@@ -7,6 +7,11 @@ from . import InvalidToken, merge_auth_info
 import logging
 
 
+def validate_config(config):
+    # file exists
+    pass
+
+
 def check_against_htpasswd(htpasswd_file, username, password):
     try:
         htpasswd = HtpasswdFile(htpasswd_file)
