@@ -13,6 +13,20 @@ this stuff is mostly from https://gitlab.com/jorgecarleitao/starlette-oauth2-api
 """
 
 
+def validate_config(config):
+    providers = config.get('providers')
+    mandatory_keys = {'issuer', 'keys', 'audience'}
+    for provider in providers:
+        if not mandatory_keys.issubset(set(providers[provider])):
+            raise ValueError(
+                f'Each provider must contain the following keys: {mandatory_keys}. Provider "{provider}" is missing {mandatory_keys - set(providers[provider])}.')
+
+        keys = providers[provider]['keys']
+        if isinstance(keys, str) and keys.startswith('http://'):
+            raise ValueError(
+                f'When "keys" is a url, it must start with "https://". This is not true in the provider "{provider}"')
+
+
 def _get_keys(url_or_keys):
     if isinstance(url_or_keys, str) and url_or_keys.startswith('https://'):
         with urllib.request.urlopen(url_or_keys) as f:
