@@ -3,6 +3,11 @@ import ipaddress
 from . import merge_auth_info
 
 
+def validate_config(config):
+    # valid networks?
+    pass
+
+
 async def process(config, scope: Scope, receive: Receive, send: Send) -> None:
     client_networks = []
     client_ip_address = ipaddress.ip_address(scope['client'][0])
