@@ -11,6 +11,10 @@ from . import merge_auth_info
 MAX_AGE: int = 31 * 24 * 60 * 60  # a month in seconds
 
 
+def validate_config(config):
+    pass
+
+
 def _get_cookie_configs(config):
     _cookie_configs = {}
     for k, v in config.items():
@@ -50,7 +54,7 @@ def _get_cookie_data(oauth2_cookie_config, cookie_data):
     return _cookie_data
 
 
-def _get_state_cookie(config, state, req_uri):
+def _create_state_cookie_data(config, state, req_uri):
     _cookie_content = {'state': state, 'type': 'state', 'request_uri': req_uri}
     data = b64encode(json.dumps(_cookie_content).encode('utf-8'))
     data = _get_signer(config).sign(data)
@@ -67,13 +71,13 @@ def _create_oauth2_redirect_response(scope, receive, name, config):
     _auth_url, state = _client.authorization_url(f"{config['idp']}/authorize")
     response = RedirectResponse(_auth_url, status_code=307)
     response.set_cookie(
-        key=name, value=_get_state_cookie(config, state, str(_request.url)),
+        key=name, value=_create_state_cookie_data(config, state, str(_request.url)),
         secure=True, samesite='none', httponly=True, expires='session',  # path=oauth2_cookie_path
     )
     return response
 
 
-def _get_token_cookie(config, token):
+def _create_token_cookie_data(config, token):
     _cookie_content = {'type': 'token', 'token': token}
     data = b64encode(json.dumps(_cookie_content).encode('utf-8'))
     data = _get_signer(config).sign(data)
@@ -105,17 +109,30 @@ async def process(config, scope: Scope, receive: Receive, send: Send) -> None:
                 _cookie_type = _cookie_data.get('type')
                 if _cookie_type is not None:
                     if _cookie_type == 'state':
-                        _code = Request(scope, receive).query_params.get('code')
-                        _token = _fetch_grant_token(config=oauth2_cookie_config, state=_cookie_data['state'],
-                                                    code=_code)
-                        _token = OAuth2Session(token=_token).access_token
+                        # read state from cookie and code from URI and fetch access_token
+                        # this breaks if multiple req were made and the state is wrong
+                        # TODO: safe state not in cookie OR all states in cookie
+                        # TODO: where to safe state - needs shared data if running in K8S with scaled deployment
                         response = RedirectResponse(_cookie_data['request_uri'], status_code=302)
-                        response.set_cookie(
-                            key=oauth2_cookie_name,
-                            value=_get_token_cookie(oauth2_cookie_config, _token),
-                            secure=True, samesite='none', httponly=True, expires='session',  # path=oauth2_cookie_path
-                        )
-                        return response(scope, receive, send)
+                        try:
+                            _code = Request(scope, receive).query_params.get('code')
+                            if _code is None or len(_code) == 0:
+                                raise Exception('no code found')
+                            _token = _fetch_grant_token(config=oauth2_cookie_config, state=_cookie_data['state'],
+                                                        code=_code)
+                            _token = OAuth2Session(token=_token).access_token
+                            response.set_cookie(
+                                key=oauth2_cookie_name,
+                                value=_create_token_cookie_data(oauth2_cookie_config, _token),
+                                secure=True, samesite='none', httponly=True, expires='session',
+                                # path=oauth2_cookie_path
+                            )
+                        except Exception as e:
+                            # sth wrong
+                            # delete cookie and redirect - will cause a loop but maybe next time it will work
+                            response.delete_cookie(key=oauth2_cookie_name)
+                        finally:
+                            return response(scope, receive, send)
                     if _cookie_type == 'token':
                         # real cookie w/ auth data
                         cookie_data.update({oauth2_cookie_name: _cookie_data.get('token')})
